@@ -181,7 +181,7 @@ eval_strstr_level (const char *string, const char *search,
 {
     const char *ptr_string;
     int level, length_search, debug_id;
-    int length_prefix, length_prefix2, length_suffix, length_suffix2;
+    int length_prefix2, length_suffix2;
 
     ptr_string = NULL;
 
@@ -196,9 +196,6 @@ eval_strstr_level (const char *string, const char *search,
 
     length_search = strlen (search);
 
-    length_prefix = strlen (eval_context->prefix);
-    length_suffix = strlen (eval_context->suffix);
-
     length_prefix2 = (extra_prefix) ? strlen (extra_prefix) : 0;
     length_suffix2 = (extra_suffix) ? strlen (extra_suffix) : 0;
 
@@ -213,10 +210,10 @@ eval_strstr_level (const char *string, const char *search,
         {
             ptr_string++;
         }
-        else if (strncmp (ptr_string, eval_context->prefix, length_prefix) == 0)
+        else if (strncmp (ptr_string, eval_context->prefix, eval_context->length_prefix) == 0)
         {
             level++;
-            ptr_string += length_prefix;
+            ptr_string += eval_context->length_prefix;
         }
         else if ((length_prefix2 > 0)
                  && (strncmp (ptr_string, extra_prefix, length_prefix2) == 0))
@@ -224,11 +221,11 @@ eval_strstr_level (const char *string, const char *search,
             level++;
             ptr_string += length_prefix2;
         }
-        else if (strncmp (ptr_string, eval_context->suffix, length_suffix) == 0)
+        else if (strncmp (ptr_string, eval_context->suffix, eval_context->length_suffix) == 0)
         {
             if (level > 0)
                 level--;
-            ptr_string += length_suffix;
+            ptr_string += eval_context->length_suffix;
         }
         else if ((length_suffix2 > 0)
                  && (strncmp (ptr_string, extra_suffix, length_suffix2) == 0))
@@ -401,6 +398,273 @@ eval_string_repeat (const char *text)
     return string_repeat (pos + 1, number);
 }
 
+/*
+ * Splits string.
+ *
+ * Format: number,separators,flags,string
+ *
+ * If number == "count", returns the number of items after split.
+ * If number == "random", returns a random item.
+ * If number > 0, return this index (empty string if not enough items).
+ * If number < 0, return this index starting from the end (-1 = last item,
+ * -2 = penultimate item, etc.).
+ *
+ * If separators is empty string, a comma is used by default.
+ *
+ * Flags is a list of flags, separated by "+":
+ *   strip_left
+ *   strip_right
+ *   collapse_seps
+ *   keep_eol
+ *   strip_items=xyz
+ *   max_items=N
+ *
+ * Examples:
+ *   ${split:1,,,abc,def,ghi}                              ==> abc
+ *   ${split:-1,,,abc,def,ghi}                             ==> ghi
+ *   ${split:count,,,abc,def,ghi}                          ==> 3
+ *   ${split:random,,,abc,def,ghi}                         ==> def
+ *   ${split:3,,collapse_seps,abc,,,def,,,ghi}             ==> ghi
+ *   ${split:3,,strip_items=-_,_-abc-_,_-def-_,_-ghi-_}    ==> ghi
+ *   ${split:2, ,,this is a test}                          ==> is
+ *   ${split:2, ,strip_left+strip_right, this is a test }  ==> is
+ *   ${split:2, ,keep_eol,this is a test}                  ==> is a test
+ *
+ * Note: result must be freed after use.
+ */
+
+char *
+eval_string_split (const char *text)
+{
+    char *pos, *pos2, *pos3, *str_number, *separators, **items, *value, *error;
+    char str_value[32], *str_flags, **list_flags, *strip_items;
+    int i, num_items, count_items, random_item, flags;
+    long number, max_items;
+
+    str_number = NULL;
+    separators = NULL;
+    items = NULL;
+    value = NULL;
+    str_flags = NULL;
+    list_flags = NULL;
+    strip_items = NULL;
+    count_items = 0;
+    random_item = 0;
+    flags = 0;
+    max_items = 0;
+
+    if (!text || !text[0])
+        goto end;
+
+    pos = strchr (text, ',');
+    if (!pos || (pos == text))
+        goto end;
+
+    number = 0;
+    str_number = string_strndup (text, pos - text);
+    if (strcmp (str_number, "count") == 0)
+    {
+        count_items = 1;
+    }
+    else if (strcmp (str_number, "random") == 0)
+    {
+        random_item = 1;
+    }
+    else
+    {
+        number = strtol (str_number, &error, 10);
+        if (!error || error[0] || (number == 0))
+            goto end;
+    }
+
+    pos++;
+    pos2 = strchr (pos, ',');
+    if (!pos2)
+        goto end;
+    if (pos2 == pos)
+        separators = strdup (",");
+    else
+        separators = string_strndup (pos, pos2 - pos);
+
+    pos2++;
+    pos3 = strchr (pos2, ',');
+    if (!pos3)
+        goto end;
+    str_flags = string_strndup (pos2, pos3 - pos2);
+    list_flags = string_split (str_flags, "+", NULL, 0, 0, NULL);
+    if (list_flags)
+    {
+        for (i = 0; list_flags[i]; i++)
+        {
+            if (strcmp (list_flags[i], "strip_left") == 0)
+                flags |= WEECHAT_STRING_SPLIT_STRIP_LEFT;
+            else if (strcmp (list_flags[i], "strip_right") == 0)
+                flags |= WEECHAT_STRING_SPLIT_STRIP_RIGHT;
+            else if (strcmp (list_flags[i], "collapse_seps") == 0)
+                flags |= WEECHAT_STRING_SPLIT_COLLAPSE_SEPS;
+            else if (strcmp (list_flags[i], "keep_eol") == 0)
+                flags |= WEECHAT_STRING_SPLIT_KEEP_EOL;
+            else if (strncmp (list_flags[i], "strip_items=", 12) == 0)
+            {
+                if (strip_items)
+                    free (strip_items);
+                strip_items = strdup (list_flags[i] + 12);
+            }
+            else if (strncmp (list_flags[i], "max_items=", 10) == 0)
+            {
+                max_items = strtol (list_flags[i] + 10, &error, 10);
+                if (!error || error[0] || (max_items < 0))
+                    goto end;
+            }
+        }
+    }
+
+    pos3++;
+
+    items = string_split (pos3, separators, strip_items, flags,
+                          max_items, &num_items);
+
+    /* if "count" was asked, return the number of items found after split */
+    if (count_items)
+    {
+        snprintf (str_value, sizeof (str_value), "%d", num_items);
+        value = strdup (str_value);
+        goto end;
+    }
+
+    if (!items || (num_items < 1))
+        goto end;
+
+    /* if "random" was asked, return a random item */
+    if (random_item)
+        number = random () % num_items;
+    else if (number > 0)
+        number--;
+
+    if (((number >= 0) && (number >= num_items))
+        || ((number < 0) && (labs (number) > num_items)))
+    {
+        goto end;
+    }
+
+    if (number < 0)
+        number = num_items + number;
+
+    value = strdup (items[number]);
+
+end:
+    if (str_number)
+        free (str_number);
+    if (separators)
+        free (separators);
+    if (str_flags)
+        free (str_flags);
+    if (list_flags)
+        string_free_split (list_flags);
+    if (strip_items)
+        free (strip_items);
+    if (items)
+        string_free_split (items);
+    return (value) ? value : strdup ("");
+}
+
+/*
+ * Splits shell arguments.
+ *
+ * Format: number,string
+ *
+ * If number == "count", returns the number of arguments.
+ * If number == "random", returns a random argument.
+ * If number > 0, return this index (empty string if not enough arguments).
+ * If number < 0, return this index starting from the end (-1 = last argument,
+ * -2 = penultimate argument, etc.).
+ *
+ * Examples:
+ *   ${split_shell:count,"arg 1" arg2}   ==> "2"
+ *   ${split_shell:random,"arg 1" arg2}  ==> "arg2"
+ *   ${split_shell:1,"arg 1" arg2}       ==> "arg 1"
+ *   ${split_shell:-1,"arg 1" arg2}      ==> "arg2"
+ *
+ * Note: result must be freed after use.
+ */
+
+char *
+eval_string_split_shell (const char *text)
+{
+    char *pos, *str_number, **items, *value, *error, str_value[32];
+    int num_items, count_items, random_item;
+    long number;
+
+    str_number = NULL;
+    items = NULL;
+    value = NULL;
+    count_items = 0;
+    random_item = 0;
+
+    if (!text || !text[0])
+        goto end;
+
+    pos = strchr (text, ',');
+    if (!pos || (pos == text))
+        goto end;
+
+    number = 0;
+    str_number = string_strndup (text, pos - text);
+    if (strcmp (str_number, "count") == 0)
+    {
+        count_items = 1;
+    }
+    else if (strcmp (str_number, "random") == 0)
+    {
+        random_item = 1;
+    }
+    else
+    {
+        number = strtol (str_number, &error, 10);
+        if (!error || error[0] || (number == 0))
+            goto end;
+    }
+
+    pos++;
+
+    items = string_split_shell (pos, &num_items);
+
+    /* if "count" was asked, return the number of items found after split */
+    if (count_items)
+    {
+        snprintf (str_value, sizeof (str_value), "%d", num_items);
+        value = strdup (str_value);
+        goto end;
+    }
+
+    if (!items || (num_items < 1))
+        goto end;
+
+    /* if "random" was asked, return a random item */
+    if (random_item)
+        number = random () % num_items;
+    else if (number > 0)
+        number--;
+
+    if (((number >= 0) && (number >= num_items))
+        || ((number < 0) && (labs (number) > num_items)))
+    {
+        goto end;
+    }
+
+    if (number < 0)
+        number = num_items + number;
+
+    value = strdup (items[number]);
+
+end:
+    if (str_number)
+        free (str_number);
+    if (items)
+        string_free_split (items);
+    return (value) ? value : strdup ("");
+}
+
 /*
  * Returns a regex group captured.
  *
@@ -416,14 +680,24 @@ eval_string_regex_group (const char *text, struct t_eval_context *eval_context)
     if (!eval_context->regex || !eval_context->regex->result)
         return strdup ("");
 
-    if (strcmp (text, "+") == 0)
-        number = eval_context->regex->last_match;
-    else if (strcmp (text, "#") == 0)
+    if (strcmp (text, "#") == 0)
     {
         snprintf (str_value, sizeof (str_value),
                   "%d", eval_context->regex->last_match);
         return strdup (str_value);
     }
+
+    if (strcmp (text, "repl_index") == 0)
+    {
+        snprintf (str_value, sizeof (str_value),
+                  "%d", eval_context->regex_replacement_index);
+        return strdup (str_value);
+    }
+
+    if (strcmp (text, "+") == 0)
+    {
+        number = eval_context->regex->last_match;
+    }
     else
     {
         number = strtol (text, &error, 10);
@@ -666,7 +940,7 @@ char *
 eval_string_if (const char *text, struct t_eval_context *eval_context)
 {
     const char *pos, *pos2;
-    char *value, *condition, *tmp, *tmp2;
+    char *value, *condition, *tmp;
     int rc;
 
     value = NULL;
@@ -679,13 +953,10 @@ eval_string_if (const char *text, struct t_eval_context *eval_context)
         strndup (text, pos - text) : strdup (text);
     if (!condition)
         return strdup ("");
-    tmp = eval_replace_vars (condition, eval_context);
-    tmp2 = eval_expression_condition ((tmp) ? tmp : "", eval_context);
-    rc = eval_is_true (tmp2);
+    tmp = eval_expression_condition (condition, eval_context);
+    rc = eval_is_true (tmp);
     if (tmp)
         free (tmp);
-    if (tmp2)
-        free (tmp2);
     if (rc)
     {
         /*
@@ -728,6 +999,98 @@ eval_string_if (const char *text, struct t_eval_context *eval_context)
     return (value) ? value : strdup ("");
 }
 
+/*
+ * Returns a random integer number.
+ *
+ * Note: result must be freed after use.
+ */
+
+char *
+eval_string_random (const char *text)
+{
+    char *pos, *error, *tmp, result[128];
+    long long min_number, max_number;
+
+    if (!text || !text[0])
+        goto error;
+
+    pos = strchr (text, ',');
+    if (!pos)
+        goto error;
+
+    tmp = strndup (text, pos - text);
+    if (!tmp)
+        goto error;
+    min_number = strtoll (tmp, &error, 10);
+    if (!error || error[0])
+    {
+        free (tmp);
+        goto error;
+    }
+    free (tmp);
+
+    max_number = strtoll (pos + 1, &error, 10);
+    if (!error || error[0])
+        goto error;
+
+    if (min_number > max_number)
+        goto error;
+    if (max_number - min_number > RAND_MAX)
+        goto error;
+
+    /*
+     * using modulo division on the random() value produces a biased result,
+     * but this is enough for our usage here
+     */
+    snprintf (result, sizeof (result),
+              "%lld", min_number + (random () % (max_number - min_number + 1)));
+    return strdup (result);
+
+error:
+    return strdup ("0");
+}
+
+/*
+ * Translates text.
+ *
+ * Note: result must be freed after use.
+ */
+
+char *
+eval_string_translate (const char *text)
+{
+    const char *ptr_string;
+
+    if (!text || !text[0])
+        return strdup ("");
+
+    ptr_string = gettext (text);
+
+    return strdup ((ptr_string) ? ptr_string : "");
+}
+
+/*
+ * Defines a variable.
+ */
+
+void
+eval_string_define (const char *text, struct t_eval_context *eval_context)
+{
+    char *pos, *name;
+
+    pos = strchr (text, ',');
+    if (!pos)
+        return;
+
+    name = strndup (text, pos - text);
+    if (!name)
+        return;
+
+    hashtable_set (eval_context->user_vars, name, pos + 1);
+
+    free (name);
+}
+
 /*
  * Gets value of hdata using "path" to a variable.
  *
@@ -744,7 +1107,9 @@ eval_hdata_get_value (struct t_hdata *hdata, void *pointer, const char *path,
     struct t_hashtable *hashtable;
 
     EVAL_DEBUG_MSG(1, "eval_hdata_get_value(\"%s\", 0x%lx, \"%s\")",
-                   hdata->name, pointer, path);
+                   (hdata) ? hdata->name : "(null)",
+                   pointer,
+                   path);
 
     value = NULL;
     var_name = NULL;
@@ -765,6 +1130,9 @@ eval_hdata_get_value (struct t_hdata *hdata, void *pointer, const char *path,
         goto end;
     }
 
+    if (!hdata)
+        goto end;
+
     /*
      * look for name of hdata, for example in "window.buffer.full_name", the
      * hdata name is "window"
@@ -903,8 +1271,8 @@ end:
 char *
 eval_string_hdata (const char *text, struct t_eval_context *eval_context)
 {
-    const char *pos, *pos1, *pos2;
-    char *value, *hdata_name, *list_name, *tmp;
+    const char *pos_vars, *pos1, *pos2;
+    char *value, *hdata_name, *pointer_name, *tmp;
     void *pointer;
     struct t_hdata *hdata;
     int rc;
@@ -912,14 +1280,16 @@ eval_string_hdata (const char *text, struct t_eval_context *eval_context)
 
     value = NULL;
     hdata_name = NULL;
-    list_name = NULL;
+    pointer_name = NULL;
     pointer = NULL;
 
-    pos = strchr (text, '.');
-    if (pos > text)
-        hdata_name = string_strndup (text, pos - text);
+    pos_vars = strchr (text, '.');
+    if (pos_vars > text)
+        hdata_name = string_strndup (text, pos_vars - text);
     else
         hdata_name = strdup (text);
+    if (pos_vars)
+        pos_vars++;
 
     if (!hdata_name)
         goto end;
@@ -928,9 +1298,12 @@ eval_string_hdata (const char *text, struct t_eval_context *eval_context)
     if (pos1 > hdata_name)
     {
         pos2 = strchr (pos1 + 1, ']');
-        if (pos2 > pos1 + 1)
+        if (pos2)
         {
-            list_name = string_strndup (pos1 + 1, pos2 - pos1 - 1);
+            if (pos2 > pos1 + 1)
+                pointer_name = string_strndup (pos1 + 1, pos2 - pos1 - 1);
+            else
+                goto end;
         }
         tmp = string_strndup (hdata_name, pos1 - hdata_name);
         if (tmp)
@@ -942,13 +1315,20 @@ eval_string_hdata (const char *text, struct t_eval_context *eval_context)
 
     hdata = hook_hdata_get (NULL, hdata_name);
     if (!hdata)
-        goto end;
-
-    if (list_name)
     {
-        if (strncmp (list_name, "0x", 2) == 0)
+        if (pos_vars || pointer_name)
+            goto end;
+        /* case of a single pointer which is not hdata, eg: ${my_pointer} */
+        pointer = hashtable_get (eval_context->pointers, hdata_name);
+        value = eval_hdata_get_value (NULL, pointer, pos_vars, eval_context);
+        goto end;
+    }
+
+    if (pointer_name)
+    {
+        if (strncmp (pointer_name, "0x", 2) == 0)
         {
-            rc = sscanf (list_name, "%lx", &ptr);
+            rc = sscanf (pointer_name, "%lx", &ptr);
             if ((rc != EOF) && (rc != 0))
             {
                 pointer = (void *)ptr;
@@ -959,7 +1339,17 @@ eval_string_hdata (const char *text, struct t_eval_context *eval_context)
                 goto end;
         }
         else
-            pointer = hdata_get_list (hdata, list_name);
+        {
+            pointer = hdata_get_list (hdata, pointer_name);
+            if (!pointer)
+            {
+                pointer = hashtable_get (eval_context->pointers, pointer_name);
+                if (!pointer)
+                    goto end;
+                if (!hdata_check_pointer (hdata, NULL, pointer))
+                    goto end;
+            }
+        }
     }
 
     if (!pointer)
@@ -967,18 +1357,17 @@ eval_string_hdata (const char *text, struct t_eval_context *eval_context)
         pointer = hashtable_get (eval_context->pointers, hdata_name);
         if (!pointer)
             goto end;
+        if (!hdata_check_pointer (hdata, NULL, pointer))
+            goto end;
     }
 
-    value = eval_hdata_get_value (hdata,
-                                  pointer,
-                                  (pos) ? pos + 1 : NULL,
-                                  eval_context);
+    value = eval_hdata_get_value (hdata, pointer, pos_vars, eval_context);
 
 end:
     if (hdata_name)
         free (hdata_name);
-    if (list_name)
-        free (list_name);
+    if (pointer_name)
+        free (pointer_name);
 
     return (value) ? value : strdup ("");
 }
@@ -986,33 +1375,44 @@ end:
 /*
  * Replaces variables, which can be, by order of priority:
  *   1. the string itself without evaluation (format: raw:xxx)
- *   2. an extra variable from hashtable "extra_vars"
- *   3. a string to evaluate (format: eval:xxx)
- *   4. a condition to evaluate (format: eval_cond:xxx)
- *   5. a string with escaped chars (format: esc:xxx or \xxx)
- *   6. a string with chars to hide (format: hide:char,string)
- *   7. a string with max chars (format: cut:max,suffix,string or
+ *   2. a variable from hashtable "user_vars" or "extra_vars"
+ *   3. a WeeChat home directory, one of: "weechat_config_dir",
+ *      "weechat_data_dir", "weechat_cache_dir", "weechat_runtime_dir"
+ *   4. a string to evaluate (format: eval:xxx)
+ *   5. a condition to evaluate (format: eval_cond:xxx)
+ *   6. a string with escaped chars (format: esc:xxx or \xxx)
+ *   7. a string with chars to hide (format: hide:char,string)
+ *   8. a string with max chars (format: cut:max,suffix,string or
  *      cut:+max,suffix,string) or max chars on screen
  *      (format: cutscr:max,suffix,string or cutscr:+max,suffix,string)
- *   8. a reversed string (format: rev:xxx) or reversed string for screen,
+ *   9. a reversed string (format: rev:xxx) or reversed string for screen,
  *      color codes are not reversed (format: revscr:xxx)
- *   9. a repeated string (format: repeat:count,string)
- *  10. length of a string (format: length:xxx) or length of a string on screen
+ *  10. a repeated string (format: repeat:count,string)
+ *  11. length of a string (format: length:xxx) or length of a string on screen
  *      (format: lengthscr:xxx); color codes are ignored
- *  11. a regex group captured (format: re:N (0.99) or re:+)
- *  12. a color (format: color:xxx)
- *  13. a modifier (format: modifier:name,data,xxx)
- *  14. an info (format: info:name,arguments)
- *  15. a base 16/32/64 encoded/decoded string (format: base_encode:base,xxx
+ *  12. split string (format: split:number,separators,flags,xxx
+ *      or split:count,separators,flags,xxx
+ *      or split:random,separators,flags,xxx)
+ *  13. split shell arguments (format: split:number,xxx or split:count,xxx
+ *      or split:random,xxx)
+ *  14. a regex group captured (format: re:N (0.99) or re:+)
+ *  15. a color (format: color:xxx)
+ *  16. a modifier (format: modifier:name,data,xxx)
+ *  17. an info (format: info:name,arguments)
+ *  18. a base 16/32/64 encoded/decoded string (format: base_encode:base,xxx
  *      or base_decode:base,xxx)
- *  16. current date/time (format: date or date:xxx)
- *  17. an environment variable (format: env:XXX)
- *  18. a ternary operator (format: if:condition?value_if_true:value_if_false)
- *  19. calculate result of an expression (format: calc:xxx)
- *  20. an option (format: file.section.option)
- *  21. a buffer local variable
- *  22. a hdata variable (format: hdata.var1.var2 or hdata[list].var1.var2
- *                        or hdata[ptr].var1.var2)
+ *  19. current date/time (format: date or date:xxx)
+ *  20. an environment variable (format: env:XXX)
+ *  21. a ternary operator (format: if:condition?value_if_true:value_if_false)
+ *  22. calculate result of an expression (format: calc:xxx)
+ *  23. a random integer number in the range from "min" to "max"
+ *      (format: random:min,max)
+ *  24. a translated string (format: translate:xxx)
+ *  25. an option (format: file.section.option)
+ *  26. a buffer local variable
+ *  27. a pointer name from hashtable "pointers"
+ *  28. a hdata variable (format: hdata.var1.var2 or hdata[list].var1.var2
+ *                        or hdata[ptr].var1.var2 or hdata[ptr_name].var1.var2)
  *
  * See /help in WeeChat for examples.
  *
@@ -1044,7 +1444,13 @@ eval_replace_vars_cb (void *data, const char *text)
         goto end;
     }
 
-    /* 2. variable in hashtable "extra_vars" */
+    /* 2. variable in hashtable "user_vars" or "extra_vars" */
+    ptr_value = hashtable_get (eval_context->user_vars, text);
+    if (ptr_value)
+    {
+        value = strdup (ptr_value);
+        goto end;
+    }
     if (eval_context->extra_vars)
     {
         ptr_value = hashtable_get (eval_context->extra_vars, text);
@@ -1069,8 +1475,30 @@ eval_replace_vars_cb (void *data, const char *text)
         }
     }
 
+    /* 3. WeeChat home directory */
+    if (strcmp (text, "weechat_config_dir") == 0)
+    {
+        value = strdup (weechat_config_dir);
+        goto end;
+    }
+    if (strcmp (text, "weechat_data_dir") == 0)
+    {
+        value = strdup (weechat_data_dir);
+        goto end;
+    }
+    if (strcmp (text, "weechat_cache_dir") == 0)
+    {
+        value = strdup (weechat_cache_dir);
+        goto end;
+    }
+    if (strcmp (text, "weechat_runtime_dir") == 0)
+    {
+        value = strdup (weechat_runtime_dir);
+        goto end;
+    }
+
     /*
-     * 3. force evaluation of string (recursive call)
+     * 4. force evaluation of string (recursive call)
      *    --> use with caution: the text must be safe!
      */
     if (strncmp (text, "eval:", 5) == 0)
@@ -1080,7 +1508,7 @@ eval_replace_vars_cb (void *data, const char *text)
     }
 
     /*
-     * 4. force evaluation of condition (recursive call)
+     * 5. force evaluation of condition (recursive call)
      *    --> use with caution: the text must be safe!
      */
     if (strncmp (text, "eval_cond:", 10) == 0)
@@ -1089,7 +1517,7 @@ eval_replace_vars_cb (void *data, const char *text)
         goto end;
     }
 
-    /* 5. convert escaped chars */
+    /* 6. convert escaped chars */
     if (strncmp (text, "esc:", 4) == 0)
     {
         value = string_convert_escaped_chars (text + 4);
@@ -1101,7 +1529,7 @@ eval_replace_vars_cb (void *data, const char *text)
         goto end;
     }
 
-    /* 6. hide chars: replace all chars by a given char/string */
+    /* 7. hide chars: replace all chars by a given char/string */
     if (strncmp (text, "hide:", 5) == 0)
     {
         value = eval_string_hide (text + 5);
@@ -1109,7 +1537,7 @@ eval_replace_vars_cb (void *data, const char *text)
     }
 
     /*
-     * 7. cut chars:
+     * 8. cut chars:
      *   cut: max number of chars, and add an optional suffix when the
      *        string is cut
      *   cutscr: max number of chars displayed on screen, and add an optional
@@ -1126,7 +1554,7 @@ eval_replace_vars_cb (void *data, const char *text)
         goto end;
     }
 
-    /* 8. reverse string */
+    /* 9. reverse string */
     if (strncmp (text, "rev:", 4) == 0)
     {
         value = string_reverse (text + 4);
@@ -1138,7 +1566,7 @@ eval_replace_vars_cb (void *data, const char *text)
         goto end;
     }
 
-    /* 9. repeated string */
+    /* 10. repeated string */
     if (strncmp (text, "repeat:", 7) == 0)
     {
         value = eval_string_repeat (text + 7);
@@ -1146,7 +1574,7 @@ eval_replace_vars_cb (void *data, const char *text)
     }
 
     /*
-     * 10. length of string:
+     * 11. length of string:
      *   length: number of chars
      *   lengthscr: number of chars displayed on screen
      */
@@ -1165,35 +1593,49 @@ eval_replace_vars_cb (void *data, const char *text)
         goto end;
     }
 
-    /* 11. regex group captured */
+    /* 12: split string */
+    if (strncmp (text, "split:", 6) == 0)
+    {
+        value = eval_string_split (text + 6);
+        goto end;
+    }
+
+    /* 13: split shell */
+    if (strncmp (text, "split_shell:", 12) == 0)
+    {
+        value = eval_string_split_shell (text + 12);
+        goto end;
+    }
+
+    /* 14. regex group captured */
     if (strncmp (text, "re:", 3) == 0)
     {
         value = eval_string_regex_group (text + 3, eval_context);
         goto end;
     }
 
-    /* 12. color code */
+    /* 15. color code */
     if (strncmp (text, "color:", 6) == 0)
     {
         value = eval_string_color (text + 6);
         goto end;
     }
 
-    /* 13. modifier */
+    /* 16. modifier */
     if (strncmp (text, "modifier:", 9) == 0)
     {
         value = eval_string_modifier (text + 9);
         goto end;
     }
 
-    /* 14. info */
+    /* 17. info */
     if (strncmp (text, "info:", 5) == 0)
     {
         value = eval_string_info (text + 5);
         goto end;
     }
 
-    /* 15. base_encode/base_decode */
+    /* 18. base_encode/base_decode */
     if (strncmp (text, "base_encode:", 12) == 0)
     {
         value = eval_string_base_encode (text + 12);
@@ -1205,14 +1647,14 @@ eval_replace_vars_cb (void *data, const char *text)
         goto end;
     }
 
-    /* 16. current date/time */
+    /* 19. current date/time */
     if ((strncmp (text, "date", 4) == 0) && (!text[4] || (text[4] == ':')))
     {
         value = eval_string_date (text + 4);
         goto end;
     }
 
-    /* 17. environment variable */
+    /* 20. environment variable */
     if (strncmp (text, "env:", 4) == 0)
     {
         ptr_value = getenv (text + 4);
@@ -1220,7 +1662,7 @@ eval_replace_vars_cb (void *data, const char *text)
         goto end;
     }
 
-    /* 18: ternary operator: if:condition?value_if_true:value_if_false */
+    /* 21: ternary operator: if:condition?value_if_true:value_if_false */
     if (strncmp (text, "if:", 3) == 0)
     {
         value = eval_string_if (text + 3, eval_context);
@@ -1228,7 +1670,7 @@ eval_replace_vars_cb (void *data, const char *text)
     }
 
     /*
-     * 19. calculate the result of an expression
+     * 22. calculate the result of an expression
      * (with number, operators and parentheses)
      */
     if (strncmp (text, "calc:", 5) == 0)
@@ -1237,7 +1679,33 @@ eval_replace_vars_cb (void *data, const char *text)
         goto end;
     }
 
-    /* 20. option: if found, return this value */
+    /*
+     * 23. random number
+     */
+    if (strncmp (text, "random:", 7) == 0)
+    {
+        value = eval_string_random (text + 7);
+        goto end;
+    }
+
+    /*
+     * 24. translated text
+     */
+    if (strncmp (text, "translate:", 10) == 0)
+    {
+        value = eval_string_translate (text + 10);
+        goto end;
+    }
+
+    /* 25. define a variable */
+    if (strncmp (text, "define:", 7) == 0)
+    {
+        eval_string_define (text + 7, eval_context);
+        value = strdup ("");
+        goto end;
+    }
+
+    /* 25. option: if found, return this value */
     if (strncmp (text, "sec.data.", 9) == 0)
     {
         ptr_value = hashtable_get (secure_hashtable_data, text + 9);
@@ -1280,7 +1748,7 @@ eval_replace_vars_cb (void *data, const char *text)
         }
     }
 
-    /* 21. local variable in buffer */
+    /* 26. local variable in buffer */
     ptr_buffer = hashtable_get (eval_context->pointers, "buffer");
     if (ptr_buffer)
     {
@@ -1292,7 +1760,7 @@ eval_replace_vars_cb (void *data, const char *text)
         }
     }
 
-    /* 22. hdata */
+    /* 27. hdata */
     value = eval_string_hdata (text, eval_context);
 
 end:
@@ -1644,7 +2112,7 @@ eval_expression_condition (const char *expr,
 
     /*
      * evaluate sub-expressions between parentheses and replace them with their
-     * value
+     * values
      */
     while (expr2[0] == '(')
     {
@@ -1762,6 +2230,7 @@ eval_replace_regex (const char *string, regex_t *regex, const char *replace,
     snprintf (result, length, "%s", string);
 
     eval_context->regex = &eval_regex;
+    eval_context->regex_replacement_index = 1;
 
     start_offset = 0;
 
@@ -1845,6 +2314,8 @@ eval_replace_regex (const char *string, regex_t *regex, const char *replace,
 
         if (!result[start_offset])
             break;
+
+        (eval_context->regex_replacement_index)++;
     }
 
 end:
@@ -1877,16 +2348,16 @@ end:
  *   >> ${window.buffer.number}
  *   == [2]
  *   >> buffer:${window.buffer.full_name}
- *   == [buffer:irc.freenode.#weechat]
+ *   == [buffer:irc.libera.#weechat]
  *   >> ${window.win_width}
  *   == [112]
  *   >> ${window.win_height}
  *   == [40]
  *
  * Examples of conditions:
- *   >> ${window.buffer.full_name} == irc.freenode.#weechat
+ *   >> ${window.buffer.full_name} == irc.libera.#weechat
  *   == [1]
- *   >> ${window.buffer.full_name} == irc.freenode.#test
+ *   >> ${window.buffer.full_name} == irc.libera.#test
  *   == [0]
  *   >> ${window.win_width} >= 30 && ${window.win_height} >= 20
  *   == [1]
@@ -1899,6 +2370,7 @@ eval_expression (const char *expr, struct t_hashtable *pointers,
                  struct t_hashtable *extra_vars, struct t_hashtable *options)
 {
     struct t_eval_context context, *eval_context;
+    struct t_hashtable *user_vars;
     int condition, rc, pointers_allocated, regex_allocated, debug_id;
     int ptr_window_added, ptr_buffer_added;
     long number;
@@ -1913,6 +2385,7 @@ eval_expression (const char *expr, struct t_hashtable *pointers,
         return NULL;
 
     condition = 0;
+    user_vars = NULL;
     pointers_allocated = 0;
     regex_allocated = 0;
     regex = NULL;
@@ -1937,14 +2410,24 @@ eval_expression (const char *expr, struct t_hashtable *pointers,
         pointers_allocated = 1;
     }
 
+    user_vars = hashtable_new (32,
+                               WEECHAT_HASHTABLE_STRING,
+                               WEECHAT_HASHTABLE_STRING,
+                               NULL,
+                               NULL);
+
     eval_context = &context;
 
     eval_context->pointers = pointers;
     eval_context->extra_vars = extra_vars;
+    eval_context->user_vars = user_vars;
     eval_context->extra_vars_eval = 0;
     eval_context->prefix = default_prefix;
+    eval_context->length_prefix = strlen (eval_context->prefix);
     eval_context->suffix = default_suffix;
+    eval_context->length_suffix = strlen (eval_context->suffix);
     eval_context->regex = NULL;
+    eval_context->regex_replacement_index = 1;
     eval_context->recursion_count = 0;
     eval_context->debug_level = 0;
     eval_context->debug_depth = 0;
@@ -1989,12 +2472,18 @@ eval_expression (const char *expr, struct t_hashtable *pointers,
         /* check for custom prefix */
         ptr_value = hashtable_get (options, "prefix");
         if (ptr_value && ptr_value[0])
+        {
             eval_context->prefix = ptr_value;
+            eval_context->length_prefix = strlen (eval_context->prefix);
+        }
 
         /* check for custom suffix */
         ptr_value = hashtable_get (options, "suffix");
         if (ptr_value && ptr_value[0])
+        {
             eval_context->suffix = ptr_value;
+            eval_context->length_suffix = strlen (eval_context->suffix);
+        }
 
         /* check for regex */
         ptr_value = hashtable_get (options, "regex");
@@ -2071,6 +2560,8 @@ eval_expression (const char *expr, struct t_hashtable *pointers,
         if (ptr_buffer_added)
             hashtable_remove (pointers, "buffer");
     }
+    if (user_vars)
+        hashtable_free (user_vars);
     if (regex && regex_allocated)
     {
         regfree (regex);
