@@ -1,7 +1,7 @@
 /*
  * wee-utf8.c - UTF-8 string functions
  *
- * Copyright (C) 2003-2015 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2021 Sébastien Helleu <flashcode@flashtux.org>
  * Copyright (C) 2006 Emmanuel Bouthenot <kolter@openics.org>
  *
  * This file is part of WeeChat, the extensible chat client.
@@ -17,7 +17,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -70,18 +70,24 @@ utf8_has_8bits (const char *string)
 /*
  * Checks if a string is UTF-8 valid.
  *
+ * If length is <= 0, checks whole string.
+ * If length is > 0, checks only this number of chars (not bytes).
+ *
  * Returns:
  *   1: string is UTF-8 valid
- *   0: string it not UTF-8 valid, and then if error is not NULL, it is set with
- *      first non valid UTF-8 char in string
+ *   0: string it not UTF-8 valid, and then if error is not NULL, it is set
+ *      with first non valid UTF-8 char in string
  */
 
 int
-utf8_is_valid (const char *string, char **error)
+utf8_is_valid (const char *string, int length, char **error)
 {
-    int code_point;
+    int code_point, current_char;
 
-    while (string && string[0])
+    current_char = 0;
+
+    while (string && string[0]
+           && ((length <= 0) || (current_char < length)))
     {
         /*
          * UTF-8, 2 bytes, should be: 110vvvvv 10vvvvvv
@@ -132,7 +138,7 @@ utf8_is_valid (const char *string, char **error)
             {
                 goto invalid;
             }
-            code_point = utf8_char_int(string);
+            code_point = utf8_char_int (string);
             if ((code_point < 0x10000) || (code_point > 0x1FFFFF))
                 goto invalid;
             string += 4;
@@ -142,6 +148,7 @@ utf8_is_valid (const char *string, char **error)
             goto invalid;
         else
             string++;
+        current_char++;
     }
     if (error)
         *error = NULL;
@@ -165,7 +172,7 @@ utf8_normalize (char *string, char replacement)
 
     while (string && string[0])
     {
-        if (utf8_is_valid (string, &error))
+        if (utf8_is_valid (string, -1, &error))
             return;
         error[0] = replacement;
         string = error + 1;
@@ -179,7 +186,7 @@ utf8_normalize (char *string, char replacement)
  * "string_start" was reached).
  */
 
-char *
+const char *
 utf8_prev_char (const char *string_start, const char *string)
 {
     if (!string || (string <= string_start))
@@ -222,7 +229,7 @@ utf8_prev_char (const char *string_start, const char *string)
  * Returns pointer to next UTF-8 char, NULL if string was NULL.
  */
 
-char *
+const char *
 utf8_next_char (const char *string)
 {
     if (!string)
@@ -426,7 +433,7 @@ utf8_char_size (const char *string)
 
 /*
  * Gets length of an UTF-8 string in number of chars (not bytes).
- * Result is <= strlen(string).
+ * Result is <= strlen (string).
  *
  * Returns length of string (>= 0).
  */
@@ -673,7 +680,7 @@ utf8_char_size_screen (const char *string)
  * Returns pointer to the new position in string.
  */
 
-char *
+const char *
 utf8_add_offset (const char *string, int offset)
 {
     if (!string)
@@ -684,7 +691,7 @@ utf8_add_offset (const char *string, int offset)
         string = utf8_next_char (string);
         offset--;
     }
-    return (char *)string;
+    return string;
 }
 
 /*
@@ -701,7 +708,7 @@ int
 utf8_real_pos (const char *string, int pos)
 {
     int count, real_pos;
-    char *next_char;
+    const char *next_char;
 
     if (!string)
         return pos;
