@@ -1,7 +1,7 @@
 /*
  * gui-curses-bar-window.c - bar window functions for Curses GUI
  *
- * Copyright (C) 2003-2015 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2021 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -16,7 +16,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -32,6 +32,7 @@
 #include "../../core/wee-log.h"
 #include "../../core/wee-string.h"
 #include "../../core/wee-utf8.h"
+#include "../../plugins/plugin.h"
 #include "../gui-bar.h"
 #include "../gui-bar-item.h"
 #include "../gui-bar-window.h"
@@ -163,6 +164,7 @@ gui_bar_window_create_win (struct t_gui_bar_window *bar_window)
 
 int
 gui_bar_window_print_string (struct t_gui_bar_window *bar_window,
+                             struct t_gui_window *window,
                              enum t_gui_bar_filling filling,
                              int *x, int *y,
                              const char *string,
@@ -170,7 +172,7 @@ gui_bar_window_print_string (struct t_gui_bar_window *bar_window,
                              int hide_chars_if_scrolling,
                              int *index_item, int *index_subitem, int *index_line)
 {
-    int x_with_hidden, size_on_screen, low_char, hidden;
+    int x_with_hidden, size_on_screen, low_char, hidden, color_bg;
     char utf_char[16], *next_char, *output;
 
     if (!bar_window || !string || !string[0])
@@ -178,11 +180,15 @@ gui_bar_window_print_string (struct t_gui_bar_window *bar_window,
 
     wmove (GUI_BAR_WINDOW_OBJECTS(bar_window)->win_bar, *y, *x);
 
+    color_bg = ((CONFIG_INTEGER(bar_window->bar->options[GUI_BAR_OPTION_TYPE]) != GUI_BAR_TYPE_ROOT)
+                && (window != gui_current_window)) ?
+        GUI_BAR_OPTION_COLOR_BG_INACTIVE : GUI_BAR_OPTION_COLOR_BG;
+
     if (reset_color_before_display)
     {
         gui_window_set_custom_color_fg_bg (GUI_BAR_WINDOW_OBJECTS(bar_window)->win_bar,
                                            CONFIG_COLOR(bar_window->bar->options[GUI_BAR_OPTION_COLOR_FG]),
-                                           CONFIG_COLOR(bar_window->bar->options[GUI_BAR_OPTION_COLOR_BG]),
+                                           CONFIG_COLOR(bar_window->bar->options[color_bg]),
                                            1);
     }
 
@@ -241,7 +247,7 @@ gui_bar_window_print_string (struct t_gui_bar_window *bar_window,
                                 /* bar background */
                                 string += 2;
                                 gui_window_set_custom_color_bg (GUI_BAR_WINDOW_OBJECTS(bar_window)->win_bar,
-                                                                CONFIG_COLOR(bar_window->bar->options[GUI_BAR_OPTION_COLOR_BG]));
+                                                                CONFIG_COLOR(bar_window->bar->options[color_bg]));
                                 break;
                             case GUI_COLOR_BAR_START_INPUT_CHAR:
                                 string += 2;
@@ -303,7 +309,7 @@ gui_bar_window_print_string (struct t_gui_bar_window *bar_window,
                         string++;
                         gui_window_set_custom_color_fg_bg (GUI_BAR_WINDOW_OBJECTS(bar_window)->win_bar,
                                                            CONFIG_COLOR(bar_window->bar->options[GUI_BAR_OPTION_COLOR_FG]),
-                                                           CONFIG_COLOR(bar_window->bar->options[GUI_BAR_OPTION_COLOR_BG]),
+                                                           CONFIG_COLOR(bar_window->bar->options[color_bg]),
                                                            0);
                         break;
                     default:
@@ -328,11 +334,11 @@ gui_bar_window_print_string (struct t_gui_bar_window *bar_window,
                                                A_ALL_ATTR);
                 gui_window_set_custom_color_fg_bg (GUI_BAR_WINDOW_OBJECTS(bar_window)->win_bar,
                                                    CONFIG_COLOR(bar_window->bar->options[GUI_BAR_OPTION_COLOR_FG]),
-                                                   CONFIG_COLOR(bar_window->bar->options[GUI_BAR_OPTION_COLOR_BG]),
+                                                   CONFIG_COLOR(bar_window->bar->options[color_bg]),
                                                    1);
                 break;
             default:
-                next_char = utf8_next_char (string);
+                next_char = (char *)utf8_next_char (string);
                 if (!next_char)
                     break;
 
@@ -408,7 +414,7 @@ void
 gui_bar_window_draw (struct t_gui_bar_window *bar_window,
                      struct t_gui_window *window)
 {
-    int x, y, items_count, num_lines, line;
+    int x, y, items_count, num_lines, line, color_bg;
     enum t_gui_bar_filling filling;
     char *content, **items;
     static char str_start_input[16] = { '\0' };
@@ -433,6 +439,10 @@ gui_bar_window_draw (struct t_gui_bar_window *bar_window,
     if (!bar_window || (bar_window->x < 0) || (bar_window->y < 0))
         return;
 
+    color_bg = ((CONFIG_INTEGER(bar_window->bar->options[GUI_BAR_OPTION_TYPE]) != GUI_BAR_TYPE_ROOT)
+                && (window != gui_current_window)) ?
+        GUI_BAR_OPTION_COLOR_BG_INACTIVE : GUI_BAR_OPTION_COLOR_BG;
+
     if (!str_start_input[0])
     {
         snprintf (str_start_input, sizeof (str_start_input), "%c%c%c",
@@ -473,6 +483,7 @@ gui_bar_window_draw (struct t_gui_bar_window *bar_window,
     content = gui_bar_window_content_get_with_filling (bar_window, window);
     if (content)
     {
+        utf8_normalize (content, '?');
         if ((filling == GUI_BAR_FILLING_HORIZONTAL)
             && (bar_window->scroll_x > 0))
         {
@@ -485,14 +496,17 @@ gui_bar_window_draw (struct t_gui_bar_window *bar_window,
             }
         }
 
-        items = string_split (content, "\n", 0, 0, &items_count);
+        items = string_split (content, "\n", NULL,
+                              WEECHAT_STRING_SPLIT_STRIP_LEFT
+                              | WEECHAT_STRING_SPLIT_STRIP_RIGHT,
+                              0, &items_count);
         if (items_count == 0)
         {
             if (CONFIG_INTEGER(bar_window->bar->options[GUI_BAR_OPTION_SIZE]) == 0)
                 gui_bar_window_set_current_size (bar_window, window, 1);
             gui_window_clear (GUI_BAR_WINDOW_OBJECTS(bar_window)->win_bar,
                               CONFIG_COLOR(bar_window->bar->options[GUI_BAR_OPTION_COLOR_FG]),
-                              CONFIG_COLOR(bar_window->bar->options[GUI_BAR_OPTION_COLOR_BG]));
+                              CONFIG_COLOR(bar_window->bar->options[color_bg]));
         }
         else
         {
@@ -547,7 +561,7 @@ gui_bar_window_draw (struct t_gui_bar_window *bar_window,
 
             gui_window_clear (GUI_BAR_WINDOW_OBJECTS(bar_window)->win_bar,
                               CONFIG_COLOR(bar_window->bar->options[GUI_BAR_OPTION_COLOR_FG]),
-                              CONFIG_COLOR(bar_window->bar->options[GUI_BAR_OPTION_COLOR_BG]));
+                              CONFIG_COLOR(bar_window->bar->options[color_bg]));
             x = 0;
             y = 0;
             some_data_not_displayed = 0;
@@ -640,7 +654,9 @@ gui_bar_window_draw (struct t_gui_bar_window *bar_window,
                 if ((bar_window->scroll_y == 0)
                     || (line >= bar_window->scroll_y))
                 {
-                    if (!gui_bar_window_print_string (bar_window, filling,
+                    if (!gui_bar_window_print_string (bar_window,
+                                                      window,
+                                                      filling,
                                                       &x, &y,
                                                       items[line], 1, 1,
                                                       &index_item,
@@ -656,7 +672,7 @@ gui_bar_window_draw (struct t_gui_bar_window *bar_window,
                         {
                             gui_window_set_custom_color_fg_bg (GUI_BAR_WINDOW_OBJECTS(bar_window)->win_bar,
                                                                CONFIG_COLOR(bar_window->bar->options[GUI_BAR_OPTION_COLOR_FG]),
-                                                               CONFIG_COLOR(bar_window->bar->options[GUI_BAR_OPTION_COLOR_BG]),
+                                                               CONFIG_COLOR(bar_window->bar->options[color_bg]),
                                                                1);
                             gui_window_remove_color_style (GUI_BAR_WINDOW_OBJECTS(bar_window)->win_bar,
                                                            A_ALL_ATTR);
@@ -669,7 +685,9 @@ gui_bar_window_draw (struct t_gui_bar_window *bar_window,
                         }
                         while (x < bar_window->width)
                         {
-                            gui_bar_window_print_string (bar_window, filling,
+                            gui_bar_window_print_string (bar_window,
+                                                         window,
+                                                         filling,
                                                          &x, &y, " ", 0, 0,
                                                          &index_item,
                                                          &index_subitem,
@@ -701,7 +719,7 @@ gui_bar_window_draw (struct t_gui_bar_window *bar_window,
                 {
                     gui_window_set_custom_color_fg_bg (GUI_BAR_WINDOW_OBJECTS(bar_window)->win_bar,
                                                        CONFIG_COLOR(config_color_bar_more),
-                                                       CONFIG_COLOR(bar_window->bar->options[GUI_BAR_OPTION_COLOR_BG]),
+                                                       CONFIG_COLOR(bar_window->bar->options[color_bg]),
                                                        1);
                     mvwaddstr (GUI_BAR_WINDOW_OBJECTS(bar_window)->win_bar,
                                y, x, ptr_string);
@@ -721,7 +739,7 @@ gui_bar_window_draw (struct t_gui_bar_window *bar_window,
                 {
                     gui_window_set_custom_color_fg_bg (GUI_BAR_WINDOW_OBJECTS(bar_window)->win_bar,
                                                        CONFIG_COLOR(config_color_bar_more),
-                                                       CONFIG_COLOR(bar_window->bar->options[GUI_BAR_OPTION_COLOR_BG]),
+                                                       CONFIG_COLOR(bar_window->bar->options[color_bg]),
                                                        1);
                     mvwaddstr (GUI_BAR_WINDOW_OBJECTS(bar_window)->win_bar,
                                y, x, ptr_string);
@@ -738,7 +756,7 @@ gui_bar_window_draw (struct t_gui_bar_window *bar_window,
             gui_bar_window_set_current_size (bar_window, window, 1);
         gui_window_clear (GUI_BAR_WINDOW_OBJECTS(bar_window)->win_bar,
                           CONFIG_COLOR(bar_window->bar->options[GUI_BAR_OPTION_COLOR_FG]),
-                          CONFIG_COLOR(bar_window->bar->options[GUI_BAR_OPTION_COLOR_BG]));
+                          CONFIG_COLOR(bar_window->bar->options[color_bg]));
     }
 
     /*
