@@ -1,7 +1,7 @@
 /*
  * gui-curses-term.c - terminal functions for Curses GUI
  *
- * Copyright (C) 2011-2015 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2011-2021 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -16,22 +16,24 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
+#ifndef WEECHAT_HEADLESS
 #ifdef HAVE_NCURSESW_CURSES_H
 #ifdef __sun
 #include <ncurses/term.h>
 #else
 #include <ncursesw/term.h>
-#endif
+#endif /* __sun */
 #else
 #include <term.h>
-#endif
+#endif /* HAVE_NCURSESW_CURSES_H */
+#endif /* WEECHAT_HEADLESS */
 
 
 /*
@@ -45,7 +47,7 @@
 void
 gui_term_set_eat_newline_glitch (int value)
 {
-#ifdef HAVE_EAT_NEWLINE_GLITCH
+#if !defined(WEECHAT_HEADLESS) && defined(HAVE_EAT_NEWLINE_GLITCH)
     eat_newline_glitch = value;
 #else
     /* make C compiler happy */
