@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2017 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2021 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef WEECHAT_GUI_CHAT_H
@@ -69,6 +69,7 @@ extern int gui_chat_display_tags;
 extern void gui_chat_init ();
 extern void gui_chat_prefix_build ();
 extern int gui_chat_utf_char_valid (const char *utf_char);
+extern int gui_chat_strlen (const char *string);
 extern int gui_chat_strlen_screen (const char *string);
 extern const char *gui_chat_string_add_offset (const char *string, int offset);
 extern const char *gui_chat_string_add_offset_screen (const char *string,
@@ -86,6 +87,8 @@ extern int gui_chat_get_time_length ();
 extern void gui_chat_change_time_format ();
 extern char *gui_chat_build_string_prefix_message (struct t_gui_line *line);
 extern char *gui_chat_build_string_message_tags (struct t_gui_line *line);
+extern int gui_chat_buffer_valid (struct t_gui_buffer *buffer,
+                                  int buffer_type);
 extern void gui_chat_printf_date_tags (struct t_gui_buffer *buffer,
                                        time_t date, const char *tags,
                                        const char *message, ...);
