@@ -59,6 +59,7 @@ struct t_config_option *buflist_config_format_lag;
 struct t_config_option *buflist_config_format_name;
 struct t_config_option *buflist_config_format_nick_prefix;
 struct t_config_option *buflist_config_format_number;
+struct t_config_option *buflist_config_format_tls_version;
 
 struct t_hook **buflist_config_signals_refresh = NULL;
 int buflist_config_num_signals_refresh = 0;
@@ -69,6 +70,27 @@ char *buflist_config_format_buffer_current_eval = NULL;
 char *buflist_config_format_hotlist_eval = NULL;
 
 
+/*
+ * Reloads buflist configuration file.
+ */
+
+int
+buflist_config_reload (const void *pointer, void *data,
+                       struct t_config_file *config_file)
+{
+    int rc;
+
+    /* make C compiler happy */
+    (void) pointer;
+    (void) data;
+
+    rc = weechat_config_reload (config_file);
+
+    buflist_add_bar ();
+
+    return rc;
+}
+
 /*
  * Frees the signals hooked for refresh.
  */
@@ -382,7 +404,7 @@ buflist_config_add_eval_for_formats (const char *string)
     char *formats[] = { "format_buffer", "format_number", "indent",
                         "format_nick_prefix", "format_name",
                         "format_hotlist", "hotlist", "format_lag",
-                        "color_hotlist", NULL };
+                        "color_hotlist", "format_tls_version", NULL };
     char *result, *tmp, format[512], format_eval[512];
     int i;
 
@@ -444,8 +466,9 @@ buflist_config_init ()
 {
     struct t_config_section *ptr_section;
 
-    buflist_config_file = weechat_config_new (BUFLIST_CONFIG_NAME,
-                                              NULL, NULL, NULL);
+    buflist_config_file = weechat_config_new (
+        BUFLIST_CONFIG_NAME,
+        &buflist_config_reload, NULL, NULL);
     if (!buflist_config_file)
         return 0;
 
@@ -576,8 +599,10 @@ buflist_config_init ()
            "char \"~\" can be used to do a case insensitive comparison; "
            "example: \"-~short_name\" for case insensitive and reverse "
            "sort on buffer short name "
-           "(note: content is evaluated, only the pointer to bar_item can be "
-           "used, for example \"bar_item.name\")"),
+           "(note: the content is evaluated, before being split into fields, "
+           "but at that time \"bar_item\" is the only variable that can be "
+           "used, to distinguish between different buflist items, for example "
+           "\"${bar_item.name}\")"),
         NULL, 0, 0, "number,-active", NULL, 0,
         NULL, NULL, NULL,
         &buflist_config_change_sort, NULL, NULL,
@@ -749,6 +774,19 @@ buflist_config_init ()
         NULL, NULL, NULL,
         &buflist_config_change_buflist, NULL, NULL,
         NULL, NULL, NULL);
+    buflist_config_format_tls_version = weechat_config_new_option (
+        buflist_config_file, ptr_section,
+        "tls_version", "string",
+        N_("format for TLS version on an IRC server buffer "
+           "(note: content is evaluated, see /help buflist)"),
+        NULL, 0, 0,
+        " ${color:default}(${if:${tls_version}==TLS1.3?${color:green}:"
+        "${if:${tls_version}==TLS1.2?${color:yellow}:${color:red}}}"
+        "${translate:${tls_version}}${color:default})",
+        NULL, 0,
+        NULL, NULL, NULL,
+        &buflist_config_change_buflist, NULL, NULL,
+        NULL, NULL, NULL);
 
     return 1;
 }
