@@ -1,7 +1,7 @@
 /*
  * exec-completion.c - completion for exec commands
  *
- * Copyright (C) 2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2014-2021 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -16,7 +16,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <stdlib.h>
@@ -32,7 +32,8 @@
  */
 
 int
-exec_completion_commands_ids_cb (void *data, const char *completion_item,
+exec_completion_commands_ids_cb (const void *pointer, void *data,
+                                 const char *completion_item,
                                  struct t_gui_buffer *buffer,
                                  struct t_gui_completion *completion)
 {
@@ -40,6 +41,7 @@ exec_completion_commands_ids_cb (void *data, const char *completion_item,
     char str_number[32];
 
     /* make C compiler happy */
+    (void) pointer;
     (void) data;
     (void) completion_item;
     (void) buffer;
@@ -47,13 +49,14 @@ exec_completion_commands_ids_cb (void *data, const char *completion_item,
     for (ptr_exec_cmd = exec_cmds; ptr_exec_cmd;
          ptr_exec_cmd = ptr_exec_cmd->next_cmd)
     {
-        snprintf (str_number, sizeof (str_number), "%d", ptr_exec_cmd->number);
-        weechat_hook_completion_list_add (completion, str_number,
-                                          0, WEECHAT_LIST_POS_SORT);
+        snprintf (str_number, sizeof (str_number),
+                  "%ld", ptr_exec_cmd->number);
+        weechat_completion_list_add (completion, str_number,
+                                     0, WEECHAT_LIST_POS_SORT);
         if (ptr_exec_cmd->name)
         {
-            weechat_hook_completion_list_add (completion, ptr_exec_cmd->name,
-                                              0, WEECHAT_LIST_POS_SORT);
+            weechat_completion_list_add (completion, ptr_exec_cmd->name,
+                                         0, WEECHAT_LIST_POS_SORT);
         }
     }
 
@@ -69,5 +72,5 @@ exec_completion_init ()
 {
     weechat_hook_completion ("exec_commands_ids",
                              N_("ids (numbers and names) of executed commands"),
-                             &exec_completion_commands_ids_cb, NULL);
+                             &exec_completion_commands_ids_cb, NULL, NULL);
 }
