@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2019 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2021 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -20,8 +20,9 @@
 #ifndef WEECHAT_PLUGIN_IRC_NICK_H
 #define WEECHAT_PLUGIN_IRC_NICK_H
 
-#define IRC_NICK_VALID_CHARS "abcdefghijklmnopqrstuvwxyzABCDEFGHI"      \
+#define IRC_NICK_VALID_CHARS_RFC1459 "abcdefghijklmnopqrstuvwxyzABCDEFGHI" \
     "JKLMNOPQRSTUVWXYZ0123456789-[]\\`_^{|}"
+#define IRC_NICK_INVALID_CHARS_RFC8265 " ,:\n\r*?.!@"
 
 /* nicklist group for nicks without prefix is "999|..." */
 #define IRC_NICK_GROUP_OTHER_NUMBER 999
@@ -47,7 +48,7 @@ struct t_irc_nick
 
 extern int irc_nick_valid (struct t_irc_channel *channel,
                            struct t_irc_nick *nick);
-extern int irc_nick_is_nick (const char *string);
+extern int irc_nick_is_nick (struct t_irc_server *server, const char *string);
 extern char *irc_nick_find_color (const char *nickname);
 extern char *irc_nick_find_color_name (const char *nickname);
 extern void irc_nick_set_host (struct t_irc_nick *nick, const char *host);
@@ -74,6 +75,8 @@ extern void irc_nick_change (struct t_irc_server *server,
 extern void irc_nick_set_mode (struct t_irc_server *server,
                                struct t_irc_channel *channel,
                                struct t_irc_nick *nick, int set, char mode);
+extern void irc_nick_realloc_prefixes (struct t_irc_server *server,
+                                       int old_length, int new_length);
 extern void irc_nick_free (struct t_irc_server *server,
                            struct t_irc_channel *channel,
                            struct t_irc_nick *nick);
