@@ -1,7 +1,7 @@
 /*
  * irc-redirect.c - redirection of IRC command output
  *
- * Copyright (C) 2010-2017 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2010-2021 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -16,7 +16,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <stdlib.h>
@@ -422,13 +422,29 @@ irc_redirect_new_with_commands (struct t_irc_server *server,
         items[i] = NULL;
     }
     if (cmd_start)
-        items[0] = weechat_string_split (cmd_start, ",", 0, 0, &num_items[0]);
+        items[0] = weechat_string_split (cmd_start, ",", NULL,
+                                         WEECHAT_STRING_SPLIT_STRIP_LEFT
+                                         | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+                                         | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+                                         0, &num_items[0]);
     if (cmd_stop)
-        items[1] = weechat_string_split (cmd_stop, ",", 0, 0, &num_items[1]);
+        items[1] = weechat_string_split (cmd_stop, ",", NULL,
+                                         WEECHAT_STRING_SPLIT_STRIP_LEFT
+                                         | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+                                         | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+                                         0, &num_items[1]);
     if (cmd_extra)
-        items[2] = weechat_string_split (cmd_extra, ",", 0, 0, &num_items[2]);
+        items[2] = weechat_string_split (cmd_extra, ",", NULL,
+                                         WEECHAT_STRING_SPLIT_STRIP_LEFT
+                                         | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+                                         | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+                                         0, &num_items[2]);
     if (cmd_filter)
-        items[3] = weechat_string_split (cmd_filter, ",", 0, 0, &num_items[3]);
+        items[3] = weechat_string_split (cmd_filter, ",", NULL,
+                                         WEECHAT_STRING_SPLIT_STRIP_LEFT
+                                         | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+                                         | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+                                         0, &num_items[3]);
     for (i = 0; i < 4; i++)
     {
         if (items[i])
@@ -686,7 +702,7 @@ irc_redirect_message_add (struct t_irc_redirect *redirect, const char *message,
     /* add message to output */
     if (redirect->output)
     {
-        redirect->output_size += strlen("\n") + strlen (message);
+        redirect->output_size += strlen ("\n") + strlen (message);
         output2 = realloc (redirect->output, redirect->output_size);
         if (!output2)
         {
@@ -793,8 +809,15 @@ irc_redirect_message (struct t_irc_server *server, const char *message,
 
     if (arguments && arguments[0])
     {
-        arguments_argv = weechat_string_split (arguments, " ", 0, 0,
-                                               &arguments_argc);
+        arguments_argv = weechat_string_split (
+            arguments,
+            " ",
+            NULL,
+            WEECHAT_STRING_SPLIT_STRIP_LEFT
+            | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+            | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+            0,
+            &arguments_argc);
     }
     else
     {
@@ -859,7 +882,7 @@ irc_redirect_message (struct t_irc_server *server, const char *message,
                 if (match_stop || ptr_redirect->cmd_start_received)
                 {
                     /*
-                     * add message to output if matching stop of if command
+                     * add message to output if matching stop or if command
                      * is numeric
                      */
                     irc_redirect_message_add (ptr_redirect, message, command);
