@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2017 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2021 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef WEECHAT_PLUGIN_LOGGER_CONFIG_H
@@ -24,12 +24,15 @@
 
 
 extern struct t_config_option *logger_config_look_backlog;
+extern struct t_config_option *logger_config_look_backlog_conditions;
 
 extern struct t_config_option *logger_config_color_backlog_end;
 extern struct t_config_option *logger_config_color_backlog_line;
 
 extern struct t_config_option *logger_config_file_auto_log;
+extern struct t_config_option *logger_config_file_color_lines;
 extern struct t_config_option *logger_config_file_flush_delay;
+extern struct t_config_option *logger_config_file_fsync;
 extern struct t_config_option *logger_config_file_info_lines;
 extern struct t_config_option *logger_config_file_mask;
 extern struct t_config_option *logger_config_file_name_lower_case;
@@ -42,6 +45,8 @@ extern struct t_config_option *logger_config_file_time_format;
 extern struct t_config_option *logger_config_get_level (const char *name);
 extern int logger_config_set_level (const char *name, const char *value);
 extern struct t_config_option *logger_config_get_mask (const char *name);
+extern void logger_config_color_lines_change (const void *pointer, void *data,
+                                              struct t_config_option *option);
 extern int logger_config_init ();
 extern int logger_config_read ();
 extern int logger_config_write ();
