@@ -602,6 +602,7 @@ plugin_load (const char *filename, int init_plugin, int argc, char **argv)
         new_plugin->gettext = &plugin_api_gettext;
         new_plugin->ngettext = &plugin_api_ngettext;
         new_plugin->strndup = &string_strndup;
+        new_plugin->string_cut = &string_cut;
         new_plugin->string_tolower = &string_tolower;
         new_plugin->string_toupper = &string_toupper;
         new_plugin->strcasecmp = &string_strcasecmp;
@@ -672,6 +673,7 @@ plugin_load (const char *filename, int init_plugin, int argc, char **argv)
         new_plugin->mkdir_parents = &dir_mkdir_parents;
         new_plugin->exec_on_files = &dir_exec_on_files;
         new_plugin->file_get_content = &dir_file_get_content;
+        new_plugin->file_copy = &dir_file_copy;
 
         new_plugin->util_timeval_cmp = &util_timeval_cmp;
         new_plugin->util_timeval_diff = &util_timeval_diff;
