@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2017 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2021 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef WEECHAT_PLUGIN_PLUGIN_H
@@ -39,15 +39,17 @@ extern const char *plugin_get_name (struct t_weechat_plugin *plugin);
 extern struct t_weechat_plugin *plugin_load (const char *filename,
                                              int init_plugin,
                                              int argc, char **argv);
-extern void plugin_auto_load (int argc, char **argv,
+extern void plugin_auto_load (char *force_plugin_autoload,
                               int load_from_plugin_path,
                               int load_from_extra_lib_dir,
-                              int load_from_lib_dir);
+                              int load_from_lib_dir,
+                              int argc,
+                              char **argv);
 extern void plugin_unload (struct t_weechat_plugin *plugin);
 extern void plugin_unload_name (const char *name);
 extern void plugin_unload_all ();
 extern void plugin_reload_name (const char *name, int argc, char **argv);
-extern void plugin_init (int auto_load, int argc, char *argv[]);
+extern void plugin_init (char *force_plugin_autoload, int argc, char *argv[]);
 extern void plugin_end ();
 extern struct t_hdata *plugin_hdata_plugin_cb (const void *pointer,
                                                void *data,
