@@ -148,8 +148,7 @@ script_config_get_diff_command ()
 }
 
 /*
- * Gets filename with script
- * (by default "/home/xxx/.weechat/script/plugins.xml.gz").
+ * Gets filename with list of scripts.
  *
  * Note: result must be freed after use.
  */
@@ -159,9 +158,19 @@ script_config_get_xml_filename ()
 {
     char *path, *filename;
     int length;
+    struct t_hashtable *options;
 
+    options = weechat_hashtable_new (
+        32,
+        WEECHAT_HASHTABLE_STRING,
+        WEECHAT_HASHTABLE_STRING,
+        NULL, NULL);
+    if (options)
+        weechat_hashtable_set (options, "directory", "cache");
     path = weechat_string_eval_path_home (
-        weechat_config_string (script_config_scripts_path), NULL, NULL, NULL);
+        weechat_config_string (script_config_scripts_path), NULL, NULL, options);
+    if (options)
+        weechat_hashtable_free (options);
     length = strlen (path) + 64;
     filename = malloc (length);
     if (filename)
@@ -172,11 +181,8 @@ script_config_get_xml_filename ()
 
 /*
  * Gets filename for a script to download.
- *
  * If suffix is not NULL, it is added to filename.
  *
- * Example: "/home/xxx/.weechat/script/go.py"
- *
  * Note: result must be freed after use.
  */
 
@@ -186,9 +192,19 @@ script_config_get_script_download_filename (struct t_script_repo *script,
 {
     char *path, *filename;
     int length;
+    struct t_hashtable *options;
 
+    options = weechat_hashtable_new (
+        32,
+        WEECHAT_HASHTABLE_STRING,
+        WEECHAT_HASHTABLE_STRING,
+        NULL, NULL);
+    if (options)
+        weechat_hashtable_set (options, "directory", "cache");
     path = weechat_string_eval_path_home (
-        weechat_config_string (script_config_scripts_path), NULL, NULL, NULL);
+        weechat_config_string (script_config_scripts_path), NULL, NULL, options);
+    if (options)
+        weechat_hashtable_free (options);
     length = strlen (path) + 1 + strlen (script->name_with_extension)
         + ((suffix) ? strlen (suffix) : 0) + 1;
     filename = malloc (length);
@@ -428,7 +444,7 @@ script_config_init ()
         script_config_file, ptr_section,
         "columns", "string",
         N_("format of columns displayed in script buffer: following column "
-           "identifiers are replaced by their value: %a=author, %d=description, "
+           "identifiers are replaced by their values: %a=author, %d=description, "
            "%D=date added, %e=extension, %l=language, %L=license, %n=name with "
            "extension, %N=name, %r=requirements, %s=status, %t=tags, "
            "%u=date updated, %v=version, %V=version loaded, %w=min_weechat, "
@@ -784,10 +800,10 @@ script_config_init ()
     script_config_scripts_path = weechat_config_new_option (
         script_config_file, ptr_section,
         "path", "string",
-        N_("local cache directory for scripts; \"%h\" at beginning of string "
-           "is replaced by WeeChat home (\"~/.weechat\" by default) "
-           "(note: content is evaluated, see /help eval)"),
-        NULL, 0, 0, "%h/script", NULL, 0,
+        N_("local cache directory for scripts "
+           "(path is evaluated, see function string_eval_path_home in "
+           "plugin API reference)"),
+        NULL, 0, 0, "${weechat_cache_dir}/script", NULL, 0,
         NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
     script_config_scripts_url = weechat_config_new_option (
         script_config_file, ptr_section,
