@@ -349,7 +349,7 @@ xfer_config_init ()
         N_("comma-separated list of nicks for which the incoming files and "
            "chats are automatically accepted; format is \"server.nick\" (for a "
            "specific server) or \"nick\" (for all servers); example: "
-           "\"freenode.FlashCode,andrew\""),
+           "\"libera.FlashCode,andrew\""),
         NULL, 0, 0, "", NULL, 0,
         NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
     xfer_config_file_auto_check_crc32 = weechat_config_new_option (
@@ -381,10 +381,10 @@ xfer_config_init ()
     xfer_config_file_download_path = weechat_config_new_option (
         xfer_config_file, ptr_section,
         "download_path", "string",
-        N_("path for writing incoming files: \"%h\" at beginning of string is "
-           "replaced by WeeChat home (\"~/.weechat\" by default) "
-           "(note: content is evaluated, see /help eval)"),
-        NULL, 0, 0, "%h/xfer", NULL, 0,
+        N_("path for writing incoming files "
+           "(path is evaluated, see function string_eval_path_home in "
+           "plugin API reference)"),
+        NULL, 0, 0, "${weechat_data_dir}/xfer", NULL, 0,
         NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
     xfer_config_file_download_temporary_suffix = weechat_config_new_option (
         xfer_config_file, ptr_section,
@@ -397,10 +397,9 @@ xfer_config_init ()
     xfer_config_file_upload_path = weechat_config_new_option (
         xfer_config_file, ptr_section,
         "upload_path", "string",
-        N_("path for reading files when sending (when no path is specified "
-           "by user): \"%h\" at beginning of string is replaced by WeeChat "
-           "home (\"~/.weechat\" by default) "
-           "(note: content is evaluated, see /help eval)"),
+        N_("path for reading files when sending "
+           "(path is evaluated, see function string_eval_path_home in "
+           "plugin API reference)"),
         NULL, 0, 0, "~", NULL, 0,
         NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
     xfer_config_file_use_nick_in_filename = weechat_config_new_option (
