@@ -249,6 +249,74 @@ TEST(IrcServer, SetPrefixModesChars)
     /* TODO: write tests */
 }
 
+/*
+ * Tests functions:
+ *   irc_server_set_clienttagdeny
+ */
+
+TEST(IrcServer, SetClienttagdeny)
+{
+    struct t_irc_server *server;
+
+    server = irc_server_alloc ("test_clienttagdeny");
+    CHECK(server);
+
+    POINTERS_EQUAL(NULL, server->clienttagdeny);
+    LONGS_EQUAL(0, server->clienttagdeny_count);
+    POINTERS_EQUAL(NULL, server->clienttagdeny_array);
+    LONGS_EQUAL(1, server->typing_allowed);
+
+    irc_server_set_clienttagdeny (server, "*");
+    irc_server_set_clienttagdeny (server, NULL);
+    POINTERS_EQUAL(NULL, server->clienttagdeny);
+    LONGS_EQUAL(0, server->clienttagdeny_count);
+    POINTERS_EQUAL(NULL, server->clienttagdeny_array);
+    LONGS_EQUAL(1, server->typing_allowed);
+
+    irc_server_set_clienttagdeny (server, "*");
+    irc_server_set_clienttagdeny (server, "");
+    POINTERS_EQUAL(NULL, server->clienttagdeny);
+    LONGS_EQUAL(0, server->clienttagdeny_count);
+    POINTERS_EQUAL(NULL, server->clienttagdeny_array);
+    LONGS_EQUAL(1, server->typing_allowed);
+
+    irc_server_set_clienttagdeny (server, "*");
+    STRCMP_EQUAL("*", server->clienttagdeny);
+    LONGS_EQUAL(1, server->clienttagdeny_count);
+    STRCMP_EQUAL("*", server->clienttagdeny_array[0]);
+    POINTERS_EQUAL(NULL, server->clienttagdeny_array[1]);
+    LONGS_EQUAL(0, server->typing_allowed);
+
+    irc_server_set_clienttagdeny (server, "*,-foo");
+    STRCMP_EQUAL("*,-foo", server->clienttagdeny);
+    LONGS_EQUAL(2, server->clienttagdeny_count);
+    STRCMP_EQUAL("*", server->clienttagdeny_array[0]);
+    STRCMP_EQUAL("!foo", server->clienttagdeny_array[1]);
+    POINTERS_EQUAL(NULL, server->clienttagdeny_array[2]);
+    LONGS_EQUAL(0, server->typing_allowed);
+
+    irc_server_set_clienttagdeny (server, "*,-foo,-example/bar");
+    STRCMP_EQUAL("*,-foo,-example/bar", server->clienttagdeny);
+    LONGS_EQUAL(3, server->clienttagdeny_count);
+    STRCMP_EQUAL("*", server->clienttagdeny_array[0]);
+    STRCMP_EQUAL("!foo", server->clienttagdeny_array[1]);
+    STRCMP_EQUAL("!example/bar", server->clienttagdeny_array[2]);
+    POINTERS_EQUAL(NULL, server->clienttagdeny_array[3]);
+    LONGS_EQUAL(0, server->typing_allowed);
+
+    irc_server_set_clienttagdeny (server, "*,-foo,-example/bar,-typing");
+    STRCMP_EQUAL("*,-foo,-example/bar,-typing", server->clienttagdeny);
+    LONGS_EQUAL(4, server->clienttagdeny_count);
+    STRCMP_EQUAL("*", server->clienttagdeny_array[0]);
+    STRCMP_EQUAL("!foo", server->clienttagdeny_array[1]);
+    STRCMP_EQUAL("!example/bar", server->clienttagdeny_array[2]);
+    STRCMP_EQUAL("!typing", server->clienttagdeny_array[3]);
+    POINTERS_EQUAL(NULL, server->clienttagdeny_array[4]);
+    LONGS_EQUAL(1, server->typing_allowed);
+
+    irc_server_free (server);
+}
+
 /*
  * Tests functions:
  *   irc_server_set_lag
@@ -980,21 +1048,19 @@ TEST_GROUP(IrcServerConnected)
 
         snprintf (str_command, sizeof (str_command),
                   "/command -buffer irc.server." IRC_FAKE_SERVER " irc "
-                  "/server fakerecv %s",
+                  "/server fakerecv \"%s\"",
                   command);
-        run_cmd (str_command);
+        run_cmd_quiet (str_command);
     }
 
     void setup ()
     {
-        printf ("\n");
-
         /* create a fake server (no I/O) */
-        run_cmd ("/server add " IRC_FAKE_SERVER " fake:127.0.0.1 "
-                 "-nicks=nick1,nick2,nick3");
+        run_cmd_quiet ("/mute /server add " IRC_FAKE_SERVER " fake:127.0.0.1 "
+                       "-nicks=nick1,nick2,nick3");
 
         /* connect to the fake server */
-        run_cmd ("/connect " IRC_FAKE_SERVER);
+        run_cmd_quiet ("/mute /connect " IRC_FAKE_SERVER);
 
         /* get the server pointer */
         ptr_server = irc_server_search (IRC_FAKE_SERVER);
@@ -1003,8 +1069,8 @@ TEST_GROUP(IrcServerConnected)
     void teardown ()
     {
         /* disconnect and delete the fake server */
-        run_cmd ("/disconnect " IRC_FAKE_SERVER);
-        run_cmd ("/server del " IRC_FAKE_SERVER);
+        run_cmd_quiet ("/mute /disconnect " IRC_FAKE_SERVER);
+        run_cmd_quiet ("/mute /server del " IRC_FAKE_SERVER);
         ptr_server = NULL;
     }
 };
@@ -1020,7 +1086,7 @@ TEST(IrcServerConnected, BuildAutojoin)
 
     server_recv (":server 001 alice");
 
-    WEE_TEST_STR("", irc_server_build_autojoin (ptr_server));
+    POINTERS_EQUAL(NULL, irc_server_build_autojoin (ptr_server));
 
     /* join one channel */
     server_recv (":alice!user@host JOIN #test1");
@@ -1028,7 +1094,7 @@ TEST(IrcServerConnected, BuildAutojoin)
 
     /* simulate a "parted" channel */
     ptr_server->channels->part = 1;
-    WEE_TEST_STR("", irc_server_build_autojoin (ptr_server));
+    POINTERS_EQUAL(NULL, irc_server_build_autojoin (ptr_server));
 
     /* restore "part" flag */
     ptr_server->channels->part = 0;
