@@ -68,8 +68,17 @@ run "cd $BUILDDIR"
 if [ "$BUILDTOOL" = "cmake" ]; then
     # build with CMake
     run "cmake .. -DENABLE_MAN=ON -DENABLE_DOC=ON -DENABLE_TESTS=ON ${BUILDARGS}"
-    run "make VERBOSE=1 -j$(nproc)"
-    run "sudo make install"
+    if [ -f "build.ninja" ]; then
+        run "ninja -v"
+        run "ninja -v changelog"
+        run "ninja -v rn"
+        run "sudo ninja install"
+    else
+        run "make VERBOSE=1 -j$(nproc)"
+        run "make VERBOSE=1 changelog"
+        run "make VERBOSE=1 rn"
+        run "sudo make install"
+    fi
     run "ctest -V"
 fi
 
